@@ -37,22 +37,30 @@
 #include "gamewidget.h"
 #include "playfield.h"
 #include "prefs.h"
+#include "commondefs.h"
+#include "chooselevelsetdialog.h"
+
+static const int LEVEL_BAR_ID = 0;
+static const int CUR_SCORE_BAR_ID = 1;
+static const int HIGHSCORE_BAR_ID = 2;
+static const int MOLECULE_NAME_ID = 3;
 
 AtomTopLevel::AtomTopLevel()
 {
-    int lastPlayed = Preferences::lastPlayedLevel();
-    int maxLevel = Preferences::maxAccessibleLevel();
+    QString lastPlayedLevelSet = Preferences::lastPlayedLevelSet();
+    if (lastPlayedLevelSet.isEmpty())
+        lastPlayedLevelSet = DEFAULT_LEVELSET_NAME;
 
-    m_gameWid = new GameWidget( qMin(lastPlayed, maxLevel), this);
+    m_gameWid = new GameWidget( lastPlayedLevelSet, this);
     m_gameWid->setObjectName("gamewidget");
     createMenu();
     loadSettings();
     setCentralWidget(m_gameWid);
 
-    statusBar()->insertItem( i18n("Level:"), 0 , 1);
-    statusBar()->insertItem( "", 3 , 1);
-    statusBar()->insertPermanentItem( i18n("Current score:"), 1, 1);
-    statusBar()->insertPermanentItem( i18n("Highscore:"), 2, 1 );
+    statusBar()->insertItem( i18n("Level:"), LEVEL_BAR_ID , 1);
+    statusBar()->insertPermanentItem( i18n("Current score:"), CUR_SCORE_BAR_ID, 1);
+    statusBar()->insertPermanentItem( i18n("Highscore:"), HIGHSCORE_BAR_ID, 1 );
+    statusBar()->insertItem( QString(), MOLECULE_NAME_ID , 1);
     statusBar()->setItemAlignment(0, Qt::AlignLeft | Qt::AlignVCenter);
 
     updateStatusBar( m_gameWid->currentLevel(), m_gameWid->currentScore(), m_gameWid->currentHighScore() );
@@ -60,8 +68,8 @@ AtomTopLevel::AtomTopLevel()
     connect(m_gameWid, SIGNAL(statsChanged(int,int,int)), SLOT(updateStatusBar(int, int, int)));
     connect(m_gameWid, SIGNAL(levelChanged(int)), SLOT(levelHasChanged(int)));
 
-    // update grayed actions
-    levelHasChanged( qMin(lastPlayed, maxLevel) );
+    // update next/prev actions
+    levelHasChanged(m_gameWid->currentLevel());
     setupGUI();
 }
 
@@ -71,7 +79,8 @@ AtomTopLevel::~AtomTopLevel()
 
 bool AtomTopLevel::queryClose()
 {
-    Preferences::setLastPlayedLevel(m_gameWid->currentLevel());
+    // saves last played level and levelset
+    m_gameWid->saveLastPlayedLevel();
     Preferences::self()->writeConfig();
     return true;
 }
@@ -106,6 +115,10 @@ void AtomTopLevel::createMenu()
     addAction( m_nextLevelAct );
     connect( m_nextLevelAct, SIGNAL( triggered( bool ) ), m_gameWid, SLOT( nextLevel() ) );
 
+    QAction* chooseLevelSet = actionCollection()->addAction( "choose_level_set" );
+    chooseLevelSet->setText( i18n( "Choose level set..." ) );
+    addAction( chooseLevelSet );
+    connect( chooseLevelSet, SIGNAL( triggered( bool ) ), SLOT( chooseLevelSet() ) );
 
     m_animSpeedAct = new KSelectAction(i18n("Animation Speed"), this);
     actionCollection()->addAction("anim_speed", m_animSpeedAct);
@@ -134,37 +147,37 @@ void AtomTopLevel::createMenu()
     connect (m_gameWid->playfield(), SIGNAL (enableUndo(bool)), undoAll, SLOT(setEnabled(bool)));
     connect (m_gameWid->playfield(), SIGNAL (enableRedo(bool)), redoAll, SLOT(setEnabled(bool)));
 
-    QAction* atomUpAct = actionCollection()->addAction("atom_up");
+    KAction* atomUpAct = actionCollection()->addAction("atom_up");
     atomUpAct->setText(i18n("Atom Up"));
     atomUpAct->setShortcut(Qt::Key_Up);
     addAction(atomUpAct);
     connect(atomUpAct, SIGNAL(triggered(bool)), m_gameWid, SLOT(moveUp()));
 
-    QAction* atomDownAct = actionCollection()->addAction("atom_down");
+    KAction* atomDownAct = actionCollection()->addAction("atom_down");
     atomDownAct->setText(i18n("Atom Down"));
     atomDownAct->setShortcut(Qt::Key_Down);
     addAction(atomDownAct);
     connect(atomDownAct, SIGNAL(triggered(bool)), m_gameWid, SLOT(moveDown()));
 
-    QAction* atomLeftAct = actionCollection()->addAction("atom_left");
+    KAction* atomLeftAct = actionCollection()->addAction("atom_left");
     atomLeftAct->setText(i18n("Atom Left"));
     atomLeftAct->setShortcut(Qt::Key_Left);
     addAction(atomLeftAct);
     connect(atomLeftAct, SIGNAL(triggered(bool)), m_gameWid, SLOT(moveLeft()));
 
-    QAction* atomRightAct = actionCollection()->addAction("atom_right");
+    KAction* atomRightAct = actionCollection()->addAction("atom_right");
     atomRightAct->setText(i18n("Atom Right"));
     atomRightAct->setShortcut(Qt::Key_Right);
     addAction(atomRightAct);
     connect(atomRightAct, SIGNAL(triggered(bool)), m_gameWid, SLOT(moveRight()));
 
-    QAction* nextAtomAct = actionCollection()->addAction("next_atom");
+    KAction* nextAtomAct = actionCollection()->addAction("next_atom");
     nextAtomAct->setText(i18n("Next Atom"));
     nextAtomAct->setShortcut(Qt::Key_Tab);
     addAction(nextAtomAct);
     connect(nextAtomAct, SIGNAL(triggered(bool)), m_gameWid->playfield(), SLOT(nextAtom()));
 
-    QAction* prevAtomAct = actionCollection()->addAction("prev_atom");
+    KAction* prevAtomAct = actionCollection()->addAction("prev_atom");
     prevAtomAct->setText(i18n("Previous Atom"));
     prevAtomAct->setShortcut(Qt::SHIFT+Qt::Key_Tab);
     addAction(prevAtomAct);
@@ -186,14 +199,14 @@ void AtomTopLevel::slotAnimSpeedChanged(int speed)
 
 void AtomTopLevel::updateStatusBar( int level, int score, int highscore )
 {
-    statusBar()->changeItem( i18n("Level: %1", level), 0 );
-    statusBar()->changeItem( i18n("Current score: %1", score), 1 );
+    statusBar()->changeItem( i18n("Level: %1 (%2)", level, m_gameWid->levelSetVisibleName()), LEVEL_BAR_ID );
+    statusBar()->changeItem( i18n("Current score: %1", score), CUR_SCORE_BAR_ID );
     QString str;
     if(highscore == 0)
         str = "-";
     else
         str.setNum(highscore);
-    statusBar()->changeItem( i18n("Highscore: %1", str), 2 );
+    statusBar()->changeItem( i18n("Highscore: %1", str), HIGHSCORE_BAR_ID );
 }
 
 void AtomTopLevel::enableHackMode()
@@ -207,18 +220,32 @@ void AtomTopLevel::enableHackMode()
 void AtomTopLevel::levelHasChanged(int level)
 {
     // Update level name
-    statusBar()->changeItem( m_gameWid->currentMolecule(), 3);
+    statusBar()->changeItem( m_gameWid->currentMolecule(), MOLECULE_NAME_ID);
     // don't gray out actions in hackmode, else do
     if(!m_gameWid->switchToAnyLevelAllowed())
         updateActionsForLevel(level);
 }
 
-void AtomTopLevel::updateActionsForLevel(int level)
+void AtomTopLevel::updateActionsForLevel(int)
 {
-    int maxLevel = Preferences::maxAccessibleLevel();
-    m_prevLevelAct->setDisabled( level == 1 );
-    m_nextLevelAct->setDisabled( level == maxLevel );
+    m_prevLevelAct->setEnabled( m_gameWid->isPrevLevelAvailable() );
+    m_nextLevelAct->setEnabled( m_gameWid->isNextLevelAvailable() );
 }
 
+void AtomTopLevel::chooseLevelSet()
+{
+    // will delete itself on close
+    ChooseLevelSetDialog* dlg = new ChooseLevelSetDialog(this);
+    connect(dlg, SIGNAL(levelSetChanged(QString)), SLOT(changeLevelSet(QString)));
+
+    dlg->setCurrentLevelSet(m_gameWid->levelSetName());
+    dlg->show();
+}
+
+void AtomTopLevel::changeLevelSet(const QString& levelSet)
+{
+    if (!levelSet.isEmpty())
+        m_gameWid->setLevelSet(levelSet);
+}
 
 #include "toplevel.moc"
