@@ -61,6 +61,7 @@ public:
     void setSoundsEnabled(bool enabled);
     void viewScaled(const QSize& newsize);
     void attemptMove(const QPoint& delta);
+    void attemptPushDown(const QPoint& delta);
     void attemptRotation(KBlocksRotationDirection direction);
 
 private:
@@ -89,6 +90,7 @@ private:
     int currentRemovedLines;
     int inLockPosition;
     int updateInterval;
+    bool firstBlock;
     
     void cleanAll();
     void levelUp();
