@@ -15,11 +15,9 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <QString>
 
 #include <KApplication>
 #include <KAboutData>
-#include <KMessageBox>
 #include <KCmdLineArgs>
 #include <KLocale>
 
@@ -37,6 +35,9 @@ int main (int argc, char *argv[])
     aboutData.addAuthor(ki18n("Eugene Trounev"), 
                         ki18n("artwork"),
                         "eugene.trounev@gmail.com");
+    aboutData.addAuthor(ki18n("Sean Wilson"),
+                        ki18n("artwork"),
+                        "suseux@gmail.com");
     aboutData.addCredit(ki18n("Lorenzo Bonomi"),
                         ki18n("testing"),
                         "lorenzo.bonomi@hotmail.it");
