@@ -19,31 +19,24 @@
 
 #include "mainwindow.h"
 
-#include <QEventLoop>
 #include <QPushButton>
-#include <QTimer>
 #include <QPainter>
 #include <QPixmap>
 #include <QPaintEvent>
 #include <QGridLayout>
 #include <QCloseEvent>
-#include <QApplication>
 
-#include <KGlobal>
 #include <KConfigDialog>
-#include <KIconLoader>
 #include <KLocale>
 #include <KStandardAction>
 #include <KAction>
 #include <KToggleAction>
 #include <KActionCollection>
 #include <KStandardGameAction>
-#include <KStatusBar>
 #include <KNotification>
 #include <KNotifyConfigWidget>
-#include <KStandardDirs>
-#include <KSelectAction>
 #include <KMessageBox>
+#include <KStatusBar>
 
 #include <KGameDifficulty>
 #include <KGameThemeSelector>
@@ -284,7 +277,7 @@ void MainWindow::kbTurnClockwise()
     if (!m_useKeyboard) {
         return;
     }
-    lClicked(m_currentCellIndex);
+    rClicked(m_currentCellIndex);
 }
 
 void MainWindow::kbTurnCounterclockwise()
@@ -292,7 +285,7 @@ void MainWindow::kbTurnCounterclockwise()
     if (!m_useKeyboard) {
         return;
     }
-    rClicked(m_currentCellIndex);
+    lClicked(m_currentCellIndex);
 }
 
 void MainWindow::kbLock()
