@@ -1,3 +1,21 @@
+/*
+ * Copyright (C) 1998-2002 Tom Holroyd <tomh@kurage.nimh.nih.gov>
+ * Copyright (C) 2006-2009 Stephan Kulow <coolo@kde.org>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of 
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 #ifndef PATSOLVE_H
 #define PATSOLVE_H
 
@@ -5,6 +23,7 @@
 #include "memory.h"
 
 #include <QtCore/QMap>
+#include <QtCore/QMutex>
 
 #include <cstdio>
 
@@ -57,6 +76,7 @@ public:
     bool recursive(POSITION *pos = 0);
     virtual void translate_layout() = 0;
     bool m_shouldEnd;
+    QMutex endMutex;
     virtual MoveHint *translateMove( const MOVE &m) = 0;
     QList<MOVE> firstMoves;
     QList<MOVE> winMoves;
@@ -128,7 +148,7 @@ protected:
 
     bool m_newer_piles_first;
     unsigned long Total_generated, Total_positions;
-    double depth_sum;
+    qreal depth_sum;
 
     POSITION *Stack;
     QMap<qint32,bool> recu_pos;
