@@ -22,16 +22,17 @@
 #include "ksirksettings.h"
 
 #include <KDebug>
+#include <KStringHandler>
+#include <kwallet.h>
 
 #include <QUuid>
 
 using namespace Ksirk;
 using namespace Ksirk::GameLogic;
 
-KsirkJabberGameWidget::KsirkJabberGameWidget(GameAutomaton* automaton,
-                                              QWidget* parent) :
+KsirkJabberGameWidget::KsirkJabberGameWidget(QWidget* parent) :
     QWidget(parent),
-    m_automaton(automaton),
+    m_automaton(0),
     m_previousGuiIndex(-1)
 {
   kDebug();
@@ -39,43 +40,35 @@ KsirkJabberGameWidget::KsirkJabberGameWidget(GameAutomaton* automaton,
   setupUi(this);
   stackedWidget->setCurrentIndex(0);
   jabberid->setText(Ksirk::KsirkSettings::jabberId());
-  password->setText(Ksirk::KsirkSettings::jabberPassword());
+
+  KWallet::Wallet* wallet = KWallet::Wallet::openWallet("ksirk", 0);
+  if (wallet == 0)
+  {
+    password->setText(KStringHandler::obscure(Ksirk::KsirkSettings::jabberPassword()));
+    roompassword->setText(KStringHandler::obscure(Ksirk::KsirkSettings::jabberPassword()));
+  }
+  else
+  {
+    if (wallet->createFolder("jabber") && wallet->setFolder("jabber"))
+    {
+      QByteArray pw;
+      wallet->readEntry("password", pw);
+      password->setText(QString::fromUtf8(pw.data()));
+      wallet->readEntry("roompassword", pw);
+      roompassword->setText(QString::fromUtf8(pw.data()));
+    }
+    delete wallet;
+  }
   roomjid->setText(Ksirk::KsirkSettings::roomJid());
-  roompassword->setText(Ksirk::KsirkSettings::roomPassword());
   nickname->setText(Ksirk::KsirkSettings::nickname());
 
-  jabberstateled->setState(
-      (m_automaton->game()->jabberClient()->isConnected())
-      ? KLed::On : KLed::Off);
+  jabberstateled->setState(KLed::Off);
   chatroomstateled->setState(KLed::Off);
       
   connect(connectbutton,SIGNAL(clicked()),this,SLOT(slotJabberConnectButtonClicked()));
-
-  connect(startnewgamebutton,SIGNAL(clicked()),m_automaton->game(),SLOT(slotNewJabberGame()));
-  
   connect(joingamebutton,SIGNAL(clicked()),this,SLOT(slotJoinJabberGame()));
-  
-  QObject::connect ( m_automaton->game()->jabberClient(), SIGNAL ( csDisconnected () ), this, SLOT ( slotJabberDisconnected() ) );
-  QObject::connect ( m_automaton->game()->jabberClient(), SIGNAL ( csError ( int ) ), this, SLOT ( slotJabberError( int ) ) );
-  QObject::connect ( m_automaton->game()->jabberClient(), SIGNAL ( tlsWarning ( QCA::TLS::IdentityResult, QCA::Validity ) ), this, SLOT ( slotHandleTLSWarning ( QCA::TLS::IdentityResult, QCA::Validity ) ) );
-  QObject::connect ( m_automaton->game()->jabberClient(), SIGNAL ( connected () ), this, SLOT ( slotJabberConnected() ) );
-  QObject::connect ( m_automaton->game()->jabberClient(), SIGNAL ( error ( JabberClient::ErrorCode ) ), this, SLOT ( slotJabberClientError( JabberClient::ErrorCode ) ) );
-
-  QObject::connect ( m_automaton->game()->jabberClient(), SIGNAL ( rosterRequestFinished ( bool ) ), this, SLOT ( slotRosterRequestFinished ( bool ) ) );
-  
   QObject::connect ( joinroombutton, SIGNAL (clicked()), this, SLOT(slotJoinRoom()));
   
-  QObject::connect ( m_automaton->game()->jabberClient(), SIGNAL (groupChatJoined (const XMPP::Jid&)), this, SLOT(slotGroupChatJoined(const XMPP::Jid&)));
-  
-  QObject::connect ( m_automaton->game()->jabberClient(), SIGNAL (groupChatLeft(const XMPP::Jid&)), this, SLOT(slotGroupChatLeft(const XMPP::Jid&)));
-  
-  QObject::connect ( m_automaton->game()->jabberClient(), SIGNAL (groupChatPresence(const XMPP::Jid&, const XMPP::Status&)), this, SLOT(slotGroupChatPresence(const XMPP::Jid&, const XMPP::Status&)));
-  
-  QObject::connect ( m_automaton->game()->jabberClient(), SIGNAL (groupChatError(const XMPP::Jid&, int, const QString&)), this, SLOT(slotGroupChatError(const XMPP::Jid&, int, const QString&)));
-
-
-  QObject::connect(automaton, SIGNAL(newJabberGame(const QString&, int, const QString&)), this, SLOT(slotNewJabberGame(const QString&, int, const QString&) ) );
-  
   QObject::connect(jabberTable, SIGNAL(cellClicked(int,int)), this, SLOT(slotCellClicked(int,int)));
   
   QStringList headers;
@@ -85,6 +78,28 @@ KsirkJabberGameWidget::KsirkJabberGameWidget(GameAutomaton* automaton,
   jabberTable->setHorizontalHeaderLabels(headers);
 
   QObject::connect(cancelbutton, SIGNAL(clicked()),this,SLOT(slotCancel()));
+}
+
+void KsirkJabberGameWidget::init(GameAutomaton* automaton)
+{
+  kDebug();
+  m_automaton = automaton;
+  jabberstateled->setState(
+      (m_automaton->game()->jabberClient()->isConnected())
+      ? KLed::On : KLed::Off);
+  
+  QObject::connect(startnewgamebutton,SIGNAL(clicked()),m_automaton->game(),SLOT(slotNewJabberGame()));
+  QObject::connect ( m_automaton->game()->jabberClient(), SIGNAL ( csDisconnected () ), this, SLOT ( slotJabberDisconnected() ) );
+  QObject::connect ( m_automaton->game()->jabberClient(), SIGNAL ( csError ( int ) ), this, SLOT ( slotJabberError( int ) ) );
+  QObject::connect ( m_automaton->game()->jabberClient(), SIGNAL ( tlsWarning ( QCA::TLS::IdentityResult, QCA::Validity ) ), this, SLOT ( slotHandleTLSWarning ( QCA::TLS::IdentityResult, QCA::Validity ) ) );
+  QObject::connect ( m_automaton->game()->jabberClient(), SIGNAL ( connected () ), this, SLOT ( slotJabberConnected() ) );
+  QObject::connect ( m_automaton->game()->jabberClient(), SIGNAL ( error ( JabberClient::ErrorCode ) ), this, SLOT ( slotJabberClientError( JabberClient::ErrorCode ) ) );
+  QObject::connect ( m_automaton->game()->jabberClient(), SIGNAL ( rosterRequestFinished ( bool ) ), this, SLOT ( slotRosterRequestFinished ( bool ) ) );
+  QObject::connect ( m_automaton->game()->jabberClient(), SIGNAL (groupChatJoined (const XMPP::Jid&)), this, SLOT(slotGroupChatJoined(const XMPP::Jid&)));
+  QObject::connect ( m_automaton->game()->jabberClient(), SIGNAL (groupChatLeft(const XMPP::Jid&)), this, SLOT(slotGroupChatLeft(const XMPP::Jid&)));
+  QObject::connect ( m_automaton->game()->jabberClient(), SIGNAL (groupChatPresence(const XMPP::Jid&, const XMPP::Status&)), this, SLOT(slotGroupChatPresence(const XMPP::Jid&, const XMPP::Status&)));
+  QObject::connect ( m_automaton->game()->jabberClient(), SIGNAL (groupChatError(const XMPP::Jid&, int, const QString&)), this, SLOT(slotGroupChatError(const XMPP::Jid&, int, const QString&)));
+  QObject::connect(automaton, SIGNAL(newJabberGame(const QString&, int, const QString&)), this, SLOT(slotNewJabberGame(const QString&, int, const QString&) ) );
   QObject::connect(this, SIGNAL(cancelled(int)), m_automaton->game(), SLOT(slotJabberGameCanceled(int)));
 }
 
@@ -95,8 +110,22 @@ void KsirkJabberGameWidget::slotJabberConnectButtonClicked()
   KsirkSettings::setJabberId(jabberid->text());
   XMPP::Jid jid(jabberid->text()+'/'+jabberid->text());
   QString pass = password->text();
-  KsirkSettings::setJabberPassword(pass);
 
+
+  KWallet::Wallet* wallet = KWallet::Wallet::openWallet("ksirk", 0);
+  if (wallet == 0)
+  {
+    KsirkSettings::setJabberPassword(KStringHandler::obscure(pass));
+  }
+  else
+  {
+    if (wallet->createFolder("jabber") && wallet->setFolder("jabber"))
+    {
+      wallet->writeEntry("password", pass.toUtf8());
+    }
+    delete wallet;
+  }
+  
   KsirkSettings::self()->writeConfig();
 
   m_automaton->game()->jabberClient()->setOverrideHost ( true, jid.domain(), 5222 );
@@ -129,7 +158,8 @@ void KsirkJabberGameWidget::slotJabberConnectButtonClicked()
     case JabberClient::MaxUsersReachedForThisMuc:
       kError() << "You can't join this Multi-User Chat because it is full";
       break;
-    default:;
+    default:
+      kError() << "Unknown error";
   }
   
 }
@@ -185,9 +215,22 @@ void KsirkJabberGameWidget::slotJoinRoom()
   m_automaton->game()->setGroupchatPassword(groupchatPassword);
   KsirkSettings::setRoomJid(groupchatRoom+'@'+groupchatHost);
   KsirkSettings::setNickname(groupchatNick);
-  KsirkSettings::setRoomPassword(groupchatPassword);
+  KWallet::Wallet* wallet = KWallet::Wallet::openWallet("ksirk", 0);
+  if (wallet == 0)
+  {
+    KsirkSettings::setRoomPassword(KStringHandler::obscure(groupchatPassword));
+  }
+  else
+  {
+    if (wallet->createFolder("jabber") && wallet->setFolder("jabber"))
+    {
+      wallet->writeEntry("roompassword", groupchatPassword.toUtf8());
+    }
+    delete wallet;
+  }
   KsirkSettings::self()->writeConfig();
 
+
   if (groupchatPassword.isEmpty())
     m_automaton->game()->jabberClient()->joinGroupChat ( groupchatHost, groupchatRoom, groupchatNick);
   else
@@ -200,12 +243,21 @@ void KsirkJabberGameWidget::slotGroupChatJoined(const XMPP::Jid & jid)
   chatroomstateled->setState(KLed::On);
 
   kDebug () << "Joined groupchat " << jid.full ();
+
+  startnewgamebutton->setEnabled(true);
+  joingamebutton->setEnabled(true);
+  loadsavedgamebutton->setEnabled(true);
 }
 
 void KsirkJabberGameWidget::slotGroupChatLeft (const XMPP::Jid & jid)
 {
   kDebug();
+  Q_UNUSED(jid);
   chatroomstateled->setState(KLed::Off);
+
+  startnewgamebutton->setEnabled(false);
+  joingamebutton->setEnabled(false);
+  loadsavedgamebutton->setEnabled(false);
 }
 
 void KsirkJabberGameWidget::slotGroupChatPresence (const XMPP::Jid & jid, const XMPP::Status & status)
@@ -230,7 +282,7 @@ void KsirkJabberGameWidget::slotGroupChatPresence (const XMPP::Jid & jid, const
 
 void KsirkJabberGameWidget::slotGroupChatError (const XMPP::Jid & jid, int error, const QString & reason)
 {
-  kDebug();
+  kDebug() << jid.full() << error << reason;
 }
 
 void KsirkJabberGameWidget::slotNewJabberGame(const QString& nick,
