@@ -25,9 +25,6 @@
 
 #include <qthread.h>
 
-#include <utility>
-
-
 namespace Ksirk
 {
 
@@ -79,7 +76,7 @@ public:
     * Saves this AI player as XML. Used in game saving.
     * @param xmlStream The stream on which to write the XML
     */
-  virtual void saveXml(std::ostream& xmlStream);
+  virtual void saveXml(QTextStream& xmlStream);
 
   bool isRunning () const {return m_thread.isRunning();}
 
@@ -96,7 +93,7 @@ protected:
 
   /** Returns a pair of countries where the attacker have enough armies to 
     * attack and the defender is a ennemy neighbour of the attacker */
-  virtual std::pair< const Country*, const Country* > chooseBelligerant();
+  virtual QPair< const Country*, const Country* > chooseBelligerant();
 
   /**
     * Chooses the next action. In the current basic setting, chooses at random
@@ -131,7 +128,7 @@ protected:
     * makes what is necessary to finish my turn
     */
   void nextPlayerAction();
-  
+
 protected: // Private attributes
   class MyThread: public QThread
   {
@@ -182,7 +179,7 @@ protected: // Private attributes
     
   bool m_hasVoted;
   bool m_actionWaitingStart;
-
+  
   MyThread m_thread;
 
 private: // Private methods
