@@ -23,22 +23,26 @@
 #include <sys/types.h>
 #include <unistd.h>
 
-#include <qfile.h>
-#include <qlayout.h>
+#include <QFile>
+#include <QLayout>
 #include <qdom.h>
+//Added by qt3to4:
+#include <QTextStream>
+#include <QVector>
+#include <kuser.h>
 
 #include <kglobal.h>
 #include <kio/netaccess.h>
 #include <kio/job.h>
 #include <kmessagebox.h>
-#include <kmdcodec.h>
+#include <kcodecs.h>
 #include <kdebug.h>
 
-#include "config.h"
 #include "kexthighscore.h"
 #include "kexthighscore_gui.h"
 #include "kemailsettings.h"
 
+#include <config-highscore.h>
 
 namespace KExtHighscore
 {
@@ -65,7 +69,7 @@ void ItemContainer::setItem(Item *item)
 QString ItemContainer::entryName() const
 {
     if ( _subGroup.isEmpty() ) return _name;
-    return _name + "_" + _subGroup;
+    return _name + '_' + _subGroup;
 }
 
 QVariant ItemContainer::read(uint i) const
@@ -108,12 +112,12 @@ ItemArray::ItemArray()
 
 ItemArray::~ItemArray()
 {
-    for (uint i=0; i<size(); i++) delete at(i);
+    for (int i=0; i<size(); i++) delete at(i);
 }
 
 int ItemArray::findIndex(const QString &name) const
 {
-    for (uint i=0; i<size(); i++)
+    for (int i=0; i<size(); i++)
         if ( at(i)->name()==name ) return i;
     return -1;
 }
@@ -121,24 +125,24 @@ int ItemArray::findIndex(const QString &name) const
 const ItemContainer *ItemArray::item(const QString &name) const
 {
     int i = findIndex(name);
-    if ( i==-1 ) kdError(11002) << k_funcinfo << "no item named \"" << name
-                                << "\"" << endl;
+    if ( i==-1 ) kError(11002) << "no item named \"" << name
+                                << "\"";
     return at(i);
 }
 
 ItemContainer *ItemArray::item(const QString &name)
 {
     int i = findIndex(name);
-    if ( i==-1 ) kdError(11002) << k_funcinfo << "no item named \"" << name
-                                << "\"" << endl;
+    if ( i==-1 ) kError(11002) << "no item named \"" << name
+                                << "\"";
     return at(i);
 }
 
 void ItemArray::setItem(const QString &name, Item *item)
 {
     int i = findIndex(name);
-    if ( i==-1 ) kdError(11002) << k_funcinfo << "no item named \"" << name
-                                << "\"" << endl;
+    if ( i==-1 ) kError(11002) << "no item named \"" << name
+                                << "\"";
     bool stored = at(i)->isStored();
     bool canHaveSubGroup = at(i)->canHaveSubGroup();
     _setItem(i, name, item, stored, canHaveSubGroup);
@@ -148,11 +152,11 @@ void ItemArray::addItem(const QString &name, Item *item,
                         bool stored, bool canHaveSubGroup)
 {
     if ( findIndex(name)!=-1 )
-        kdError(11002) << "item already exists \"" << name << "\"" << endl;
-    uint i = size();
-    resize(i+1);
-    at(i) = new ItemContainer;
-    _setItem(i, name, item, stored, canHaveSubGroup);
+        kError(11002) << "item already exists \"" << name << "\"";
+
+    append(new ItemContainer);
+    //at(i) = new ItemContainer;
+    _setItem(size()-1, name, item, stored, canHaveSubGroup);
 }
 
 void ItemArray::_setItem(uint i, const QString &name, Item *item,
@@ -160,15 +164,15 @@ void ItemArray::_setItem(uint i, const QString &name, Item *item,
 {
     at(i)->setItem(item);
     at(i)->setName(name);
-    at(i)->setGroup(stored ? _group : QString::null);
-    at(i)->setSubGroup(canHaveSubGroup ? _subGroup : QString::null);
+    at(i)->setGroup(stored ? _group : QString());
+    at(i)->setSubGroup(canHaveSubGroup ? _subGroup : QString());
 }
 
 void ItemArray::setGroup(const QString &group)
 {
     Q_ASSERT( !group.isNull() );
     _group = group;
-    for (uint i=0; i<size(); i++)
+    for (int i=0; i<size(); i++)
         if ( at(i)->isStored() ) at(i)->setGroup(group);
 }
 
@@ -176,13 +180,13 @@ void ItemArray::setSubGroup(const QString &subGroup)
 {
     Q_ASSERT( !subGroup.isNull() );
     _subGroup = subGroup;
-    for (uint i=0; i<size(); i++)
+    for (int i=0; i<size(); i++)
         if ( at(i)->canHaveSubGroup() ) at(i)->setSubGroup(subGroup);
 }
 
 void ItemArray::read(uint k, Score &data) const
 {
-    for (uint i=0; i<size(); i++) {
+    for (int i=0; i<size(); i++) {
         if ( !at(i)->isStored() ) continue;
         data.setData(at(i)->name(), at(i)->read(k));
     }
@@ -190,7 +194,7 @@ void ItemArray::read(uint k, Score &data) const
 
 void ItemArray::write(uint k, const Score &data, uint nb) const
 {
-    for (uint i=0; i<size(); i++) {
+    for (int i=0; i<size(); i++) {
         if ( !at(i)->isStored() ) continue;
         for (uint j=nb-1; j>k; j--)  at(i)->write(j, at(i)->read(j-1));
         at(i)->write(k, data.data(at(i)->name()));
@@ -200,7 +204,7 @@ void ItemArray::write(uint k, const Score &data, uint nb) const
 void ItemArray::exportToText(QTextStream &s) const
 {
     for (uint k=0; k<nbEntries()+1; k++) {
-        for (uint i=0; i<size(); i++) {
+        for (int i=0; i<size(); i++) {
             const Item *item = at(i)->item();
             if ( item->isVisible() ) {
                 if ( i!=0 ) s << '\t';
@@ -269,7 +273,7 @@ PlayerInfos::PlayerInfos()
     it = Manager::createItem(Manager::BestScoreDefault);
     addItem("best score", it, true, true);
     addItem("date", new DateItem, true, true);
-    it = new Item(QString::null, i18n("Comment"), Qt::AlignLeft);
+    it = new Item(QString(), i18n("Comment"), Qt::AlignLeft);
     addItem("comment", it);
 
     // statistics items
@@ -280,8 +284,8 @@ PlayerInfos::PlayerInfos()
     addItem("max lost trend", new Item((uint)0), true, true);
     addItem("max won trend", new Item((uint)0), true, true);
 
-    struct passwd *pwd = getpwuid(getuid());
-    QString username = pwd->pw_name;
+    QString username = KUser().loginName();
+ 
 #ifdef HIGHSCORE_DIRECTORY
     internal->hsConfig().setHighscoreGroup("players");
     for (uint i=0; ;i++) {
@@ -309,12 +313,16 @@ PlayerInfos::PlayerInfos()
 #endif
 
     ConfigGroup cg;
-    _oldLocalPlayer = cg.config()->hasKey(HS_ID);
-    _oldLocalId = cg.config()->readUnsignedNumEntry(HS_ID);
+    _oldLocalPlayer = cg.hasKey(HS_ID);
+    _oldLocalId = cg.readEntry(HS_ID).toUInt();
 #ifdef HIGHSCORE_DIRECTORY
     if (_oldLocalPlayer) { // player already exists in local config file
         // copy player data
         QString prefix = QString("%1_").arg(_oldLocalId+1);
+#ifdef __GNUC__
+#warning "kde4 port g.config()->entryMap";
+#endif
+#if 0
         QMap<QString, QString> entries =
             cg.config()->entryMap("KHighscore_players");
         QMap<QString, QString>::const_iterator it;
@@ -326,13 +334,14 @@ PlayerInfos::PlayerInfos()
                     internal->hsConfig().writeEntry(_id+1, name, it.data());
             }
         }
-    }
+#endif
+    }    
 #else
     _newPlayer = !_oldLocalPlayer;
     if (_oldLocalPlayer) _id = _oldLocalId;
     else {
         _id = nbEntries();
-        cg.config()->writeEntry(HS_ID, _id);
+        cg.writeEntry(HS_ID, _id);
         item("name")->write(_id, name);
     }
 #endif
@@ -340,12 +349,12 @@ PlayerInfos::PlayerInfos()
     internal->hsConfig().writeAndUnlock();
 }
 
-void PlayerInfos::createHistoItems(const QMemArray<uint> &scores, bool bound)
+void PlayerInfos::createHistoItems(const QVector<uint> &scores, bool bound)
 {
     Q_ASSERT( _histogram.size()==0 );
     _bound = bound;
     _histogram = scores;
-    for (uint i=1; i<histoSize(); i++)
+    for (int i=1; i<histoSize(); i++)
         addItem(histoName(i), new Item((uint)0), true, true);
 }
 
@@ -364,25 +373,25 @@ uint PlayerInfos::nbEntries() const
 QString PlayerInfos::key() const
 {
     ConfigGroup cg;
-    return cg.config()->readEntry(HS_KEY, QString::null);
+    return cg.readEntry(HS_KEY, QString());
 }
 
 bool PlayerInfos::isWWEnabled() const
 {
     ConfigGroup cg;
-    return cg.config()->readBoolEntry(HS_WW_ENABLED, false);
+    return cg.readEntry(HS_WW_ENABLED, false);
 }
 
-QString PlayerInfos::histoName(uint i) const
+QString PlayerInfos::histoName(int i) const
 {
-    const QMemArray<uint> &sh = _histogram;
+    const QVector<uint> &sh = _histogram;
     Q_ASSERT( i<sh.size() || (_bound || i==sh.size()) );
     if ( i==sh.size() )
         return QString("nb scores greater than %1").arg(sh[sh.size()-1]);
     return QString("nb scores less than %1").arg(sh[i]);
 }
 
-uint PlayerInfos::histoSize() const
+int PlayerInfos::histoSize() const
 {
      return _histogram.size() + (_bound ? 0 : 1);
 }
@@ -413,7 +422,7 @@ void PlayerInfos::submitScore(const Score &score) const
     }
 
     // update best score
-    Score best = score; // copy optionnal fields (there are not taken into account here)
+    Score best = score; // copy optional fields (there are not taken into account here)
     best.setScore( item("best score")->read(_id).toUInt() );
     if ( best<score ) {
         item("best score")->write(_id, score.score());
@@ -446,8 +455,8 @@ void PlayerInfos::submitScore(const Score &score) const
 
     // update histogram
     if ( score.type()==Won ) {
-        const QMemArray<uint> &sh = _histogram;
-        for (uint i=1; i<histoSize(); i++)
+        const QVector<uint> &sh = _histogram;
+        for (int i=1; i<histoSize(); i++)
             if ( i==sh.size() || score.score()<sh[i] ) {
                 item(histoName(i))->increment(_id);
                 break;
@@ -459,7 +468,7 @@ bool PlayerInfos::isNameUsed(const QString &newName) const
 {
     if ( newName==name() ) return false; // own name...
     for (uint i=0; i<nbEntries(); i++)
-        if ( newName.lower()==item("name")->read(i).toString().lower() ) return true;
+        if ( newName.toLower()==item("name")->read(i).toString().toLower() ) return true;
     if ( newName==i18n(ItemContainer::ANONYMOUS_LABEL) ) return true;
     return false;
 }
@@ -476,15 +485,15 @@ void PlayerInfos::modifySettings(const QString &newName,
     modifyName(newName);
     item("comment")->write(_id, comment);
     ConfigGroup cg;
-    cg.config()->writeEntry(HS_WW_ENABLED, WWEnabled);
-    if ( !newKey.isEmpty() ) cg.config()->writeEntry(HS_KEY, newKey);
-    if (WWEnabled) cg.config()->writeEntry(HS_REGISTERED_NAME, newName);
+    cg.writeEntry(HS_WW_ENABLED, WWEnabled);
+    if ( !newKey.isEmpty() ) cg.writeEntry(HS_KEY, newKey);
+    if (WWEnabled) cg.writeEntry(HS_REGISTERED_NAME, newName);
 }
 
 QString PlayerInfos::registeredName() const
 {
     ConfigGroup cg;
-    return cg.config()->readEntry(HS_REGISTERED_NAME, QString::null);
+    return cg.readEntry(HS_REGISTERED_NAME, QString());
 }
 
 void PlayerInfos::removeKey()
@@ -498,15 +507,15 @@ void PlayerInfos::removeKey()
     do {
         i++;
         sk = str.arg(HS_KEY).arg(i);
-    } while ( !cg.config()->readEntry(sk, QString::null).isEmpty() );
-    cg.config()->writeEntry(sk, key());
-    cg.config()->writeEntry(str.arg(HS_REGISTERED_NAME).arg(i),
+    } while ( !cg.readEntry(sk, QString()).isEmpty() );
+    cg.writeEntry(sk, key());
+    cg.writeEntry(str.arg(HS_REGISTERED_NAME).arg(i),
                             registeredName());
 
     // clear current key/nickname
-    cg.config()->deleteEntry(HS_KEY);
-    cg.config()->deleteEntry(HS_REGISTERED_NAME);
-    cg.config()->writeEntry(HS_WW_ENABLED, false);
+    cg.deleteEntry(HS_KEY);
+    cg.deleteEntry(HS_REGISTERED_NAME);
+    cg.writeEntry(HS_WW_ENABLED, false);
 }
 
 //-----------------------------------------------------------------------------
@@ -531,9 +540,9 @@ ManagerPrivate::~ManagerPrivate()
     delete _hsConfig;
 }
 
-KURL ManagerPrivate::queryURL(QueryType type, const QString &newName) const
+KUrl ManagerPrivate::queryUrl(QueryType type, const QString &newName) const
 {
-    KURL url = serverURL;
+    KUrl url = serverURL;
     QString nameItem = "nickname";
     QString name = _playerInfos->registeredName();
     bool withVersion = true;
@@ -602,20 +611,20 @@ const char *DUMMY_STRINGS[] = {
 const char *UNABLE_TO_CONTACT =
     I18N_NOOP("Unable to contact world-wide highscore server");
 
-bool ManagerPrivate::doQuery(const KURL &url, QWidget *parent,
+bool ManagerPrivate::doQuery(const KUrl &url, QWidget *parent,
                                 QDomNamedNodeMap *map)
 {
     KIO::http_update_cache(url, true, 0); // remove cache !
 
     QString tmpFile;
     if ( !KIO::NetAccess::download(url, tmpFile, parent) ) {
-        QString details = i18n("Server URL: %1").arg(url.host());
+        QString details = i18n("Server URL: %1", url.host());
         KMessageBox::detailedSorry(parent, i18n(UNABLE_TO_CONTACT), details);
         return false;
     }
 
 	QFile file(tmpFile);
-	if ( !file.open(IO_ReadOnly) ) {
+	if ( !file.open(QIODevice::ReadOnly) ) {
         KIO::NetAccess::removeTempFile(tmpFile);
         QString details = i18n("Unable to open temporary file.");
         KMessageBox::detailedSorry(parent, i18n(UNABLE_TO_CONTACT), details);
@@ -623,7 +632,7 @@ bool ManagerPrivate::doQuery(const KURL &url, QWidget *parent,
     }
 
 	QTextStream t(&file);
-	QString content = t.read().stripWhiteSpace();
+	QString content = t.readAll().trimmed();
 	file.close();
     KIO::NetAccess::removeTempFile(tmpFile);
 
@@ -638,7 +647,7 @@ bool ManagerPrivate::doQuery(const KURL &url, QWidget *parent,
         if ( element.tagName()=="error" ) {
             QDomAttr attr = element.attributes().namedItem("label").toAttr();
             if ( !attr.isNull() ) {
-                QString msg = i18n(attr.value().latin1());
+                QString msg = i18n(attr.value().toLatin1());
                 QString caption = i18n("Message from world-wide highscores "
                                        "server");
                 KMessageBox::sorry(parent, msg, caption);
@@ -647,7 +656,7 @@ bool ManagerPrivate::doQuery(const KURL &url, QWidget *parent,
         }
     }
     QString msg = i18n("Invalid answer from world-wide highscores server.");
-    QString details = i18n("Raw message: %1").arg(content);
+    QString details = i18n("Raw message: %1", content);
     KMessageBox::detailedSorry(parent, msg, details);
     return false;
 }
@@ -660,7 +669,7 @@ bool ManagerPrivate::getFromQuery(const QDomNamedNodeMap &map,
     if ( attr.isNull() ) {
 	    KMessageBox::sorry(parent,
                i18n("Invalid answer from world-wide "
-                    "highscores server (missing item: %1).").arg(name));
+                    "highscores server (missing item: %1).", name));
 		return false;
     }
     value = attr.value();
@@ -693,7 +702,7 @@ bool ManagerPrivate::modifySettings(const QString &newName,
     if (WWEnabled) {
         newPlayer = _playerInfos->key().isEmpty()
                     || _playerInfos->registeredName().isEmpty();
-        KURL url = queryURL((newPlayer ? Register : Change), newName);
+        KUrl url = queryUrl((newPlayer ? Register : Change), newName);
         Manager::addToQueryURL(url, "comment", comment);
 
         QDomNamedNodeMap map;
@@ -720,15 +729,15 @@ void ManagerPrivate::convertToGlobal()
     // read old highscores
     KHighscore *tmp = _hsConfig;
     _hsConfig = new KHighscore(true, 0);
-    QValueVector<Score> scores(_scoreInfos->nbEntries());
-    for (uint i=0; i<scores.count(); i++)
+    QVector<Score> scores(_scoreInfos->nbEntries());
+    for (int i=0; i<scores.count(); i++)
         scores[i] = readScore(i);
 
     // commit them
     delete _hsConfig;
     _hsConfig = tmp;
     _hsConfig->lockForWriting();
-    for (uint i=0; i<scores.count(); i++)
+    for (int i=0; i<scores.count(); i++)
         if ( scores[i].data("id").toUInt()==_playerInfos->oldLocalId()+1 )
             submitLocal(scores[i]);
     _hsConfig->writeAndUnlock();
@@ -758,12 +767,12 @@ void ManagerPrivate::setGameType(uint type)
     }
 
     Q_ASSERT( type<_nbGameTypes );
-    _gameType = kMin(type, _nbGameTypes-1);
+    _gameType = qMin(type, _nbGameTypes-1);
     QString str = "scores";
     QString lab = manager.gameTypeLabel(_gameType, Manager::Standard);
     if ( !lab.isEmpty() ) {
         _playerInfos->setSubGroup(lab);
-        str += "_" + lab;
+        str += '_' + lab;
     }
     _scoreInfos->setGroup(str);
 }
@@ -830,12 +839,12 @@ bool ManagerPrivate::submitWorldWide(const Score &score,
     if ( score.type()==Lost && !trackLostGames ) return true;
     if ( score.type()==Draw && !trackDrawGames ) return true;
 
-    KURL url = queryURL(Submit);
+    KUrl url = queryUrl(Submit);
     manager.additionalQueryItems(url, score);
     int s = (score.type()==Won ? score.score() : (int)score.type());
     QString str =  QString::number(s);
     Manager::addToQueryURL(url, "score", str);
-    KMD5 context(QString(_playerInfos->registeredName() + str).latin1());
+    KMD5 context(QString(_playerInfos->registeredName() + str).toLatin1());
     Manager::addToQueryURL(url, "check", context.hexDigest());
 
     return doQuery(url, widget);
@@ -851,8 +860,7 @@ void ManagerPrivate::exportHighscores(QTextStream &s)
             if ( i!=0 ) s << endl;
             s << "--------------------------------" << endl;
             s << "Game type: "
-              << manager.gameTypeLabel(_gameType, Manager::I18N)
-              << endl;
+              << manager.gameTypeLabel(_gameType, Manager::I18N) << endl;
             s << endl;
         }
         s << "Players list:" << endl;
