@@ -20,6 +20,7 @@
 #include "kcarddialog.h"
 #include "ui_kgamecardselector.h"
 
+#include <QPainter>
 #include <QPixmap>
 #include <QListWidgetItem>
 #include <QFileInfo>
@@ -54,8 +55,7 @@ public:
     */
   bool filterOutCard(const KCardThemeInfo& v)
   {
-    if (!ui.checkBoxPNG->isChecked() && v.svgfile.isEmpty()) return true;
-    return false;
+    return !fixedSizeAllowed && v.svgfile.isEmpty();
   }
 
   /** Currently chosen back side name.
@@ -66,6 +66,10 @@ public:
    */
   QString currentFront;
 
+  /** Determines if PNG based decks should be shown
+   */
+  bool fixedSizeAllowed;
+
   /** The UI elements.
    */
   Ui::KGameCardSelectorBase ui;
@@ -80,6 +84,8 @@ KCardWidget::KCardWidget(QWidget* parent)
   setupGUI();
   setLocked(true);
   setFixedSizeAllowed(false);
+  insertCardIcons();
+  insertDeckIcons();
   setFrontName(CardDeckInfo::defaultFrontName(false));
   setBackName(CardDeckInfo::defaultBackName(false));
 }
@@ -87,7 +93,6 @@ KCardWidget::KCardWidget(QWidget* parent)
 void KCardWidget::readSettings(const KConfigGroup& group)
 {
   setLocked(CardDeckInfo::lockFrontToBackside(group));
-  setFixedSizeAllowed(CardDeckInfo::allowFixedSizeDecks(group));
   setFrontName(CardDeckInfo::frontTheme(group));
   setBackName(CardDeckInfo::backTheme(group));
 }
@@ -95,8 +100,7 @@ void KCardWidget::readSettings(const KConfigGroup& group)
 // Store the config group settings
 void KCardWidget::saveSettings(KConfigGroup& group) const
 {
-  CardDeckInfo::writeLockFrontToBackside(group, d->ui.checkBoxLock->isChecked());
-  CardDeckInfo::writeAllowFixedSizeDecks(group, d->ui.checkBoxPNG->isChecked());
+  CardDeckInfo::writeLockFrontToBackside(group, !d->ui.backGroupBox->isChecked());
   CardDeckInfo::writeFrontTheme(group, d->currentFront);
   CardDeckInfo::writeBackTheme(group, d->currentBack);
 }
@@ -118,8 +122,7 @@ void KCardWidget::setupGUI()
           this, SLOT(updateFront()));
   connect(ui->backList, SIGNAL(itemSelectionChanged()),
           this, SLOT(updateBack()));
-  connect(ui->checkBoxLock, SIGNAL(toggled(bool)), this, SLOT(setLocked(bool)));
-  connect(ui->checkBoxPNG, SIGNAL(toggled(bool)), this, SLOT(setFixedSizeAllowed(bool)));
+  connect(ui->backGroupBox, SIGNAL(toggled(bool)), this, SLOT(setNotLocked(bool)));
 
   // Debug
   // kDebug() << "DEFAULT DECK: " << defaultDeckName(pAllowSVG, pAllowPNG);
@@ -150,18 +153,17 @@ QString KCardWidget::frontName() const
 
 bool KCardWidget::isFixedSizeAllowed() const
 {
-  return d->ui.checkBoxPNG->isChecked();
+  return d->fixedSizeAllowed;
 }
 
 bool KCardWidget::isLocked() const
 {
-  return d->ui.checkBoxLock->isChecked();
+  return !d->ui.backGroupBox->isChecked();
 }
 
 // Build list widget
 void KCardWidget::insertCardIcons()
 {
-
   // Clear GUI
   d->ui.frontList->clear();
 
@@ -173,7 +175,13 @@ void KCardWidget::insertCardIcons()
     // Show only SVG files?
     if (d->filterOutCard(v)) continue;
 
-    QPixmap previewPixmap = v.preview.scaled(QSize(32,43), Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+    const int iconSize = 48;
+    QPixmap resizedCard = v.preview.scaled(QSize(iconSize, iconSize), Qt::KeepAspectRatio, Qt::SmoothTransformation);
+    QPixmap previewPixmap(iconSize, iconSize);
+    previewPixmap.fill(Qt::transparent);
+    QPainter p(&previewPixmap);
+    p.drawPixmap((iconSize-resizedCard.width())/2, (iconSize-resizedCard.height())/2, resizedCard);
+    p.end();
 
     QListWidgetItem *item = new QListWidgetItem(v.name, d->ui.frontList);
     item->setFlags(Qt::ItemIsEnabled | Qt::ItemIsSelectable);
@@ -225,9 +233,11 @@ void KCardWidget::setFrontName(const QString& name)
       if (item->data(Qt::UserRole).toString() == name)
       {
         item->setSelected(true);
+        d->ui.frontList->scrollToItem(item);
         break;
       }
     }
+
     KCardThemeInfo info = CardDeckInfo::frontInfo(name);
     QFont font;
     font.setBold(true);
@@ -260,7 +270,7 @@ void KCardWidget::setFrontName(const QString& name)
 // Update the locking filter
 void KCardWidget::setLocked(bool locked)
 {
-  d->ui.checkBoxLock->setChecked(locked);
+  d->ui.backGroupBox->setChecked(!locked);
   if (locked)
   {
     // Update previews
@@ -269,13 +279,22 @@ void KCardWidget::setLocked(bool locked)
   d->ui.backList->setEnabled(!locked);
 }
 
+// An ugly internal slot needed for UI connections
+void KCardWidget::setNotLocked(bool notLocked)
+{
+    setLocked(!notLocked);
+}
+
 
 // Update the PNG status filter
 void KCardWidget::setFixedSizeAllowed(bool allowFixedSize)
 {
-  d->ui.checkBoxPNG->setChecked(allowFixedSize);
-  insertCardIcons();
-  insertDeckIcons();
+    if ( allowFixedSize != d->fixedSizeAllowed )
+    {
+        d->fixedSizeAllowed = allowFixedSize;
+        insertCardIcons();
+        insertDeckIcons();
+    }
 }
 
 
@@ -306,6 +325,7 @@ void KCardWidget::setBackName(const QString& item)
       if (lwi->data(Qt::UserRole).toString() == item)
       {
         lwi->setSelected(true);
+        d->ui.backList->scrollToItem(lwi);
         break;
       }
     }
@@ -334,7 +354,14 @@ void KCardWidget::insertDeckIcons()
     KCardThemeInfo v = CardDeckInfo::backInfo(name);
     // Show only SVG files?
     if (d->filterOutCard(v) || v.preview.isNull() ) continue;
-    QPixmap previewPixmap = v.preview.scaled(QSize(32,43), Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+
+    const int iconSize = 48;
+    QPixmap resizedCard = v.preview.scaled(QSize(iconSize, iconSize), Qt::KeepAspectRatio, Qt::SmoothTransformation);
+    QPixmap previewPixmap(iconSize, iconSize);
+    previewPixmap.fill(Qt::transparent);
+    QPainter p(&previewPixmap);
+    p.drawPixmap((iconSize-resizedCard.width())/2, (iconSize-resizedCard.height())/2, resizedCard);
+    p.end();
 
     QListWidgetItem *item = new QListWidgetItem(v.name, d->ui.backList);
     item->setFlags(Qt::ItemIsEnabled | Qt::ItemIsSelectable);
@@ -355,7 +382,7 @@ void KCardWidget::insertDeckIcons()
 KCardDialog::KCardDialog( KCardWidget* widget )
 {
   setMainWidget(widget);
-  setCaption(i18n("Carddeck Selection"));
+  setCaption(i18n("Card Deck Selection"));
   setButtons(KDialog::Ok | KDialog::Cancel);
 }
 
